==> nextcloud-18.0.4.tar.bz2: nextcloud/apps/files/l10n/nb.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Storage invalid" : "Lagringsplass ugyldig",
    "Unknown error" : "Ukjent feil",
    "All files" : "Alle filer",
    "Recent" : "Nylig",
    "Favorites" : "Favoritter",
    "File could not be found" : "Filen ble ikke funnet",
    "Move or copy" : "Flytt eller kopier",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "Home" : "Hjem",
    "Close" : "Lukk",
    "Could not create folder \"{dir}\"" : "Klarete ikke å opprette mappe \"{dir}\"",
    "This will stop your current uploads." : "Dette fille stoppe dine nåværende opplastinger.",
    "Upload cancelled." : "Opplasting avbrutt.",
    "Processing files …" : "Prosesserer filer…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 Byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp {size1} men bare {size2} er ledig",
    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
    "Not enough free space" : "Ikke nok ledig diskplass",
    "An unknown error has occurred" : "En ukjent feil oppstod",
    "Uploading …" : "Laster opp…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Opplastning av det elementet er ikke støttet",
    "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
    "Error when assembling chunks, status code {status}" : "Feil under sammenkobling av biter, statuskode {status}",
    "Actions" : "Handlinger",
    "Rename" : "Gi nytt navn",
    "Copy" : "Kopier",
    "Choose target folder" : "Velg målmappe",
    "Open" : "Åpne",
    "Delete file" : "Slett fil",
    "Delete folder" : "Slett mappe",
    "Disconnect storage" : "Koble fra lager",
    "Unshare" : "Opphev deling",
    "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Velg",
    "Pending" : "Venter",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "copy" : "kopier",
    "Could not copy \"{file}\", target exists" : "Klarte ikke å kopiere \"{file}\", målfilen finnes",
    "Could not copy \"{file}\"" : "Klarte ikke å kopiere \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
    "{newName} already exists" : "{newName} finnes allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
    "Could not rename \"{fileName}\"" : "Klarte ikke å gi \"{fileName}\" nytt navn",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create folder \"{dir}\" because it already exists" : "Klarete ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søkeresultater i andre mapper etter {tag}{filter}{endtag}",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
    "New" : "Ny",
    "{used} of {quota} used" : "{used} av {quota} brukt",
    "{used} used" : "{used} brukt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagringsplass for {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringsplass er nesten brukt opp ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : [" stemmer med '{filter}'"," stemmer med '{filter}'"],
    "View in folder" : "Vis i mappe",
    "Copied!" : "Kopiert!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte lenke (virker bare for brukere som har tilgang til denne filen/mappa)",
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Favorisert",
    "Favorite" : "Gjør til favoritt",
    "New folder" : "Ny mappe",
    "Upload file" : "Last opp fil",
    "Not favorited" : "Ikke i favoritter",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av merkelappene",
    "Added to favorites" : "Lagt til i favoritter",
    "Removed from favorites" : "Fjernet fra favoritter",
    "You added {file} to your favorites" : "Du la til {file} i dine favoritter",
    "You removed {file} from your favorites" : "Du fjernet {file} fra dine favoritter",
    "File changes" : "Filendringer",
    "Created by {user}" : "Opprettet av {user}",
    "Changed by {user}" : "Endret av {user}",
    "Deleted by {user}" : "Slettet av {user}",
    "Restored by {user}" : "Gjenopprettet av {user}",
    "Renamed by {user}" : "Navn endret av {user}",
    "Moved by {user}" : "Flyttet av {user}",
    "\"remote user\"" : "\"ekstern bruker\"",
    "You created {file}" : "Du opprettet {file}",
    "You created an encrypted file in {file}" : "Du opprettet en kryptert fil i {file}",
    "{user} created {file}" : "{user} opprettet {file}",
    "{user} created an encrypted file in {file}" : "{user} opprettet en kryptert fil i {file}",
    "{file} was created in a public folder" : "{file} ble opprettet i en offentlig mappe",
    "You changed {file}" : "Du endret {file}",
    "You changed an encrypted file in {file}" : "Du endret en kryptert fil i {file}",
    "{user} changed {file}" : "{user} endret {file}",
    "{user} changed an encrypted file in {file}" : "{user} endret en kryptert fil i {file}",
    "You deleted {file}" : "Du slettet {file}",
    "You deleted an encrypted file in {file}" : "Du slette en kryptert fil i {file}",
    "{user} deleted {file}" : "{user} slettet {file}",
    "{user} deleted an encrypted file in {file}" : "{user} slettet en kryptert fil i {file}",
    "You restored {file}" : "Du gjenopprettet {file}",
    "{user} restored {file}" : "{user} gjenopprettet {file}",
    "You renamed {oldfile} to {newfile}" : "Du endret navn på {oldfile} til {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} endret navn på {oldfile} til {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttet {oldfile} til {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttet {oldfile} til {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har blitt lagt til eller fjernet fra dine <strong>favoritter</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil eller mappe ble <strong>endret</strong> eller <strong>omdøpt</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mappe ble <strong>opprettet</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe ble <strong>slettet</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begrens varsling om oppretting og endringer til <strong>favorittfilene</strong> dine <em>(Kun strøm)</em>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe ble <strong>gjenopprettet</strong>",
    "Unlimited" : "Ubegrenset",
    "Upload (max. %s)" : "Opplasting (maks %s)",
    "Accept" : "Aksepter",
    "File Management" : "Filbehandling",
    "Change" : "Endre",
    "Tags" : "Merkelapper",
    "%s used" : "%s brukt",
    "%1$s of %2$s used" : "%1$s av %2$s brukt",
    "Settings" : "Innstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Toggle grid view" : "Veksle rutenett-visning",
    "No files in here" : "Ingen filer",
    "Upload some content or sync with your devices!" : "Last opp innhold eller synkroniser med enhetene dine!",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
    "No favorites yet" : "Ingen favoritter enda",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
    "Deleted files" : "Slettede filer",
    "Shares" : "Delinger",
    "Shared with others" : "Delt med andre",
    "Shared with you" : "Delt med deg",
    "Shared by link" : "Delt med lenke",
    "Deleted shares" : "Slettede delinger",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekstfil.txt",
    "%s of %s used" : "%s av %s brukt",
    "%1$s%% of %2$s used" : "%1$s%% av %2$s brukt",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Bruk adressen <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">for å få tilgang til dine filer via WebDAV</a>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/files/l10n/nb.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Storage invalid" : "Lagringsplass ugyldig",
    "Unknown error" : "Ukjent feil",
    "File could not be found" : "Filen ble ikke funnet",
    "Move or copy" : "Flytt eller kopier",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "Tags" : "Merkelapper",
    "Show list view" : "Vis listevisning",
    "Show grid view" : "Vis rutenett-visning",
    "Home" : "Hjem",
    "Close" : "Lukk",
    "Favorites" : "Favoritter",
    "Could not create folder \"{dir}\"" : "Kunne ikke å opprette mappe \"{dir}\"",
    "This will stop your current uploads." : "Dette vil stoppe dine nåværende opplastinger.",
    "Upload cancelled." : "Opplasting avbrutt.",
    "Processing files …" : "Prosesserer filer…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 Byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp {size1} men bare {size2} er ledig",
    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
    "Not enough free space" : "Ikke nok ledig diskplass",
    "An unknown error has occurred" : "En ukjent feil oppstod",
    "File could not be uploaded" : "Fil kunne ikke lastes opp",
    "Uploading …" : "Laster opp…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Opplastning av det elementet er ikke støttet",
    "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
    "Operation is blocked by access control" : "Operasjonen er blokkert på grunn av tilgangskontroll",
    "Error when assembling chunks, status code {status}" : "Feil under sammenkobling av biter, statuskode {status}",
    "Actions" : "Handlinger",
    "Rename" : "Gi nytt navn",
    "Move" : "Flytt",
    "Copy" : "Kopier",
    "Choose target folder" : "Velg målmappe",
    "Open" : "Åpne",
    "Delete file" : "Slett fil",
    "Delete folder" : "Slett mappe",
    "Disconnect storage" : "Koble fra lager",
    "Leave this share" : "Forlat denne delingen",
    "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select directory \"{dirName}\"" : "Velg mappe \"{dirName}\"",
    "Select file \"{fileName}\"" : "Velg fil \"{fileName}\"",
    "Pending" : "Venter",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "copy" : "kopier",
    "Could not copy \"{file}\", target exists" : "Klarte ikke å kopiere \"{file}\", målfilen finnes",
    "Could not copy \"{file}\"" : "Klarte ikke å kopiere \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
    "{newName} already exists" : "{newName} finnes allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
    "Could not rename \"{fileName}\"" : "Klarte ikke å gi \"{fileName}\" nytt navn",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
    "Could not fetch file details \"{file}\"" : "Kunne ikke hente fildetaljene \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søkeresultater i andre mapper etter {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Tast inn mer enn to tegn for å lete i andre mapper",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
    "You do not have permission to upload or create files here" : "Du har ikke tilgang til å laste opp eller opprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
    "New file/folder menu" : "Ny fil/mappe-meny",
    "Select file range" : "Velg filutvalg",
    "{used} of {quota} used" : "{used} av {quota} brukt",
    "{used} used" : "{used} brukt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppemappen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Den eksterne lagringsplassen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Din lagringsplass er nesten full ({usedSpacePercent}%).",
    "View in folder" : "Vis i mappe",
    "Copied!" : "Kopiert!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte lenke (virker bare for brukere som har tilgang til denne filen/mappa)",
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Favorisert",
    "Favorite" : "Gjør til favoritt",
    "You can only favorite a single file or folder at a time" : "Du kan bare legge til en fil av gangen til favoritter",
    "New folder" : "Ny mappe",
    "Upload file" : "Last opp fil",
    "Recent" : "Nylig",
    "Not favorited" : "Ikke i favoritter",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av merkelappene",
    "Added to favorites" : "Lagt til i favoritter",
    "Removed from favorites" : "Fjernet fra favoritter",
    "You added {file} to your favorites" : "Du la til {file} i dine favoritter",
    "You removed {file} from your favorites" : "Du fjernet {file} fra dine favoritter",
    "File changes" : "Filendringer",
    "Created by {user}" : "Opprettet av {user}",
    "Changed by {user}" : "Endret av {user}",
    "Deleted by {user}" : "Slettet av {user}",
    "Restored by {user}" : "Gjenopprettet av {user}",
    "Renamed by {user}" : "Navn endret av {user}",
    "Moved by {user}" : "Flyttet av {user}",
    "\"remote user\"" : "\"ekstern bruker\"",
    "You created {file}" : "Du opprettet {file}",
    "You created an encrypted file in {file}" : "Du opprettet en kryptert fil i {file}",
    "{user} created {file}" : "{user} opprettet {file}",
    "{user} created an encrypted file in {file}" : "{user} opprettet en kryptert fil i {file}",
    "{file} was created in a public folder" : "{file} ble opprettet i en offentlig mappe",
    "You changed {file}" : "Du endret {file}",
    "You changed an encrypted file in {file}" : "Du endret en kryptert fil i {file}",
    "{user} changed {file}" : "{user} endret {file}",
    "{user} changed an encrypted file in {file}" : "{user} endret en kryptert fil i {file}",
    "You deleted {file}" : "Du slettet {file}",
    "You deleted an encrypted file in {file}" : "Du slette en kryptert fil i {file}",
    "{user} deleted {file}" : "{user} slettet {file}",
    "{user} deleted an encrypted file in {file}" : "{user} slettet en kryptert fil i {file}",
    "You restored {file}" : "Du gjenopprettet {file}",
    "{user} restored {file}" : "{user} gjenopprettet {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Du endret navn på {oldfile} (skjult) til {newfile} (skjult)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Du endret navn på {oldfile} (skjult) til {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Du endret navn på {oldfile} til {newfile} (skjult)",
    "You renamed {oldfile} to {newfile}" : "Du endret navn på {oldfile} til {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : " {user} endret navn på {oldfile} (skjult) til {newfile} (skjult)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : " {user} endret navn på {oldfile} (skjult) til {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} endret navn på {oldfile} til {newfile} (skjult)",
    "{user} renamed {oldfile} to {newfile}" : " {user} endret navn på {oldfile} til {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttet {oldfile} til {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttet {oldfile} til {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har blitt lagt til eller fjernet fra dine <strong>favoritter</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe ble <strong>endret</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "En favoritt-fil eller mappe har blitt <strong>endret</strong>",
    "All files" : "Alle filer",
    "Unlimited" : "Ubegrenset",
    "Upload (max. %s)" : "Opplasting (maks %s)",
    "Accept" : "Aksepter",
    "Reject" : "Avvis",
    "Incoming ownership transfer from {user}" : "Ny eierskapsoverføring fra {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ønsker du å godta {path}?\n\nObs: Overføringsprosessen kan ta opp til 1 time.",
    "Ownership transfer failed" : "Overføring av eierskap mislyktes",
    "Your ownership transfer of {path} to {user} failed." : "Eierskapsoverføring din av {path} til {user} mislyktes.",
    "The ownership transfer of {path} from {user} failed." : "Eierskapsoverføring av {path} fra {user} mislyktes.",
    "Ownership transfer done" : "Overføring av eierskap ferdig",
    "Your ownership transfer of {path} to {user} has completed." : "Eierskapsoverføringen din av {path} til {user} er ferdig.",
    "The ownership transfer of {path} from {user} has completed." : "Eierskapsoverføring av {path} fra {user} er ferdig.",
    "in %s" : "om %s",
    "File Management" : "Filbehandling",
    "Transfer ownership of a file or folder" : "Eierskapsoverføring av en fil eller mappe",
    "Choose file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
    "Change" : "Endre",
    "New owner" : "Ny eier",
    "Search users" : "Søk etter brukere",
    "Choose a file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
    "Transfer" : "Overfør",
    "Transfer {path} to {userid}" : "Overfør {path} til {userid}",
    "Invalid path selected" : "Ugyldig angitt sti",
    "Ownership transfer request sent" : "Forespørsel om overføring av eierskap er sendt",
    "Unable to change the favourite state of the file" : "Kan ikke endre favorittstatus til filen",
    "Error while loading the file data" : "Feil ved lasting av fildata",
    "Cancel" : "Avbryt",
    "Create" : "Opprett",
    "Creating file" : "Oppretter fil",
    "%s used" : "%s brukt",
    "%1$s of %2$s used" : "%1$s av %2$s brukt",
    "Files settings" : "Filinnstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
    "Toggle grid view" : "Veksle rutenett-visning",
    "No files in here" : "Ingen filer",
    "Upload some content or sync with your devices!" : "Last opp innhold eller synkroniser med enhetene dine!",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
    "No favorites yet" : "Ingen favoritter enda",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
    "Deleted files" : "Slettede filer",
    "Shares" : "Delinger",
    "Shared with others" : "Delt med andre",
    "Shared with you" : "Delt med deg",
    "Shared by link" : "Delt med lenke",
    "Deleted shares" : "Slettede delinger",
    "Pending shares" : "Ventende delinger",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekstfil.txt",
    "Select" : "Velg",
    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
    "New" : "Ny",
    "Cannot transfer ownership of a file or folder you don't own" : "Kan ikke overføre eierskap til en fil eller mappe du ikke eier",
    "%s%% of %s used" : "%s%% av %s brukt",
    "Settings" : "Innstillinger"
},
"nplurals=2; plural=(n != 1);");
